
import { useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { ArrowLeft, ArrowRight, Loader2 } from 'lucide-react';
import { toast } from "sonner";
import Navbar from '@/components/Navbar';
import {
  PersonalInfoSection,
  FinancialInfoSection,
  GeographicInfoSection,
  CreditHistorySection,
  SpendingHistorySection
} from '@/components/FormSections';
import { Button } from '@/components/ui/button';
import { predictDefaultRisk } from '@/lib/predictionModel';
import { useAuth } from '@/contexts/AuthContext';

const PredictionForm = () => {
  const navigate = useNavigate();
  const { user } = useAuth();
  const [formData, setFormData] = useState({});
  const [isSubmitting, setIsSubmitting] = useState(false);

  // Scroll to top on load
  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  const handleSubmit = async (e) => {
    e.preventDefault();
    
    // Validate form data
    const requiredFields = ['name', 'monthlyIncome', 'residenceArea'];
    const missingFields = requiredFields.filter(field => !formData[field]);
    
    if (missingFields.length > 0) {
      toast.error("Missing required fields", {
        description: "Please fill in all the required fields to continue.",
      });
      return;
    }
    
    setIsSubmitting(true);
    
    try {
      // Process the form data with AI-enhanced prediction
      toast.info("Processing assessment", {
        description: "Our AI is analyzing the financial data...",
      });
      
      // Call the predictDefaultRisk function, which now includes AI enhancement
      const results = await predictDefaultRisk(formData);
      
      // Store results in sessionStorage to pass to results page
      sessionStorage.setItem('predictionResults', JSON.stringify(results));
      sessionStorage.setItem('clientData', JSON.stringify(formData));
      
      // Navigate to results page
      navigate('/results');
    } catch (error) {
      console.error("Error processing assessment:", error);
      toast.error("Error processing assessment", {
        description: "There was an error processing your assessment. Please try again.",
      });
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <div className="min-h-screen bg-gradient-to-b from-white to-gray-50">
      <Navbar />
      
      <main className="pt-32 pb-16">
        <div className="container max-w-4xl mx-auto px-4">
          <button 
            onClick={() => navigate(-1)}
            className="flex items-center gap-1 text-muted-foreground hover:text-foreground transition-colors mb-8"
          >
            <ArrowLeft size={16} />
            <span>Back</span>
          </button>
          
          <div className="mb-8 animate-fade-up">
            <h1 className="heading-lg mb-2">Credit Risk Assessment Form</h1>
            <p className="text-lg text-muted-foreground">
              Fill in the client's information to generate a comprehensive risk assessment.
            </p>
          </div>
          
          <form onSubmit={handleSubmit} className="space-y-6">
            <PersonalInfoSection formData={formData} setFormData={setFormData} />
            <FinancialInfoSection formData={formData} setFormData={setFormData} />
            <GeographicInfoSection formData={formData} setFormData={setFormData} />
            <CreditHistorySection formData={formData} setFormData={setFormData} />
            <SpendingHistorySection formData={formData} setFormData={setFormData} />
            
            <div className="flex justify-end pt-4 animate-fade-up" style={{ animationDelay: '0.5s' }}>
              <Button 
                type="submit" 
                className="button-primary"
                disabled={isSubmitting}
              >
                {isSubmitting ? (
                  <>
                    <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                    Processing
                  </>
                ) : (
                  <>
                    Generate Assessment
                    <ArrowRight size={18} className="ml-2" />
                  </>
                )}
              </Button>
            </div>
          </form>
        </div>
      </main>
    </div>
  );
};

export default PredictionForm;
